@@ -16,7 +16,7 @@
 
 """boggleboard.py
 
-A class to generate and manipulate Boggle-style boards. Boards of different
+A package to generate and manipulate Boggle-style boards. Boards of different
 sizes can be randomly generated, and given a list of acceptable words (in the
 form of a Trie - see below), the package can find all words in a particular
 Boggle board.
@@ -50,6 +50,21 @@ Note that this module contains the following structures:
 By using a graph to represent the adjacency of positions in a board, subclasses
 of AbstractBoggleBoard can be created to represent any geometric board.
 
+To simply create a random Boggle board:
+    import boggleboard
+    b = boggleboard.BoggleBoard()
+    b.generateBoard()
+
+To create a specific board, say r1=SGTI r2=YAKH r3=ASRN r4=PTOD, and find all
+words of length 4 or higher in YAWL:
+    import boggleboard
+    import boggleboard.yawl
+    t = boggleboard.Trie(boggleboard.yawl.wordList)
+    b = boggleboard.BoggleBoard('SGTIYAKHASRNPTOD')
+    # Or alternatively b = boggleboard.BoggleBoard(['S', 'G', 'T', 'I', 'Y', ...])
+    # Note we need to use a list if 'QU' is on the board.
+    b.findWords(t, 4)
+
 By Sebastian Raaphorst, 2009."""
 
 import sys
@@ -119,7 +134,7 @@ defaultTiles = ['a']*9 + ['b']*2 + ['c']*2 + ['d']*4 + ['e']*11 + ['f']*2 + ['g'
 
 
 def wordSorter(x,y):
-    """wordSorter(x,y):
+    """wordSorter(x,y)
 
     Function to determine the relative order of two words, x and y.
     Words are first sorted by length in nonincreasing order, and then lexicographically."""
@@ -195,7 +210,7 @@ class Trie:
 
 
     def getRoot(self):
-        """getRoot:
+        """getRoot
 
         Returns a pointer to the root node. This is used in trie traversal."""
 
@@ -203,7 +218,7 @@ class Trie:
 
 
     def getChild(self, node, child):
-        """getChild(node, child):
+        """getChild(node, child)
 
         Return a pointer to the specified child of the given node, if one exists. If it does
         not, return -1."""
@@ -214,7 +229,7 @@ class Trie:
 
 
     def isTerminal(self, node):
-        """isTerminal(node):
+        """isTerminal(node)
 
         Return whether or not the specified node is a terminal node."""
 
@@ -222,7 +237,7 @@ class Trie:
 
 
     def contains(self, theList):
-        """contains(theList):
+        """contains(theList)
 
         Determine if the trie contains elem. Returns True if it does, and False otherwise."""
 
@@ -249,7 +264,7 @@ class AbstractBoggleBoard:
     letter unscrambling (i.e. using n=7 would give a standard Scrabble hand)."""
 
     def __init__(self, numLetters, layout=None):
-        """__init__(numLetters, layout=None):
+        """__init__(numLetters, layout=None)
 
         Create a new Boggle board with the specified number of letters. If
         layout is given, it should be a list of length numLetters indicating
@@ -263,7 +278,7 @@ class AbstractBoggleBoard:
 
 
     def _determineAdjacencies(self):
-        """_determineAdjacencies()
+        """_determineAdjacencies
 
         Creates an adjacency list representation of the graph representing
         the adjacencies of the boggle board.
@@ -280,7 +295,7 @@ class AbstractBoggleBoard:
 
 
     def generateBoard(self, dice, seed=-1):
-        """generateBoard(self):
+        """generateBoard(dice, seed=-1):
 
         Generate a random board. Note that dice should be an array of length at
         least numLetters, with each entry consisting of a list of the possible
@@ -323,7 +338,7 @@ class AbstractBoggleBoard:
     
 
     def findWords(self, wordTrie, minimumSize=3):
-        """findWords(wordTrie, minimumSize=3):
+        """findWords(wordTrie, minimumSize=3)
 
         Given a Trie, as per the trie module, backtrack through the Boggle board
         to locate all possible words. A list of words, sorted by size and then
@@ -437,7 +452,7 @@ class AbstractBoggleBoard:
 
 
     def __str__(self):
-        """__str__:
+        """__str__
 
         Convert a Boggle board to a readable string.
         In the abstract case, this is just a list of the contents for each
@@ -456,7 +471,7 @@ class RectangularBoggleBoard(AbstractBoggleBoard):
     visualization, may be displayed as such."""
 
     def __init__(self, length, width, layout=None):
-        """__init__(length, width, layout=None):
+        """__init__(length, width, layout=None)
 
         Create a new length X width Boggle board. If the layout is specified, it
         should be a linear array of size length X width indicating the contents
@@ -469,7 +484,7 @@ class RectangularBoggleBoard(AbstractBoggleBoard):
 
 
     def _determineAdjacencies(self):
-        """_determineAdjacencies()
+        """_determineAdjacencies
 
         Creates an adjacency list representation of the graph representing
         the adjacencies of a standard rectangular boggle board."""
@@ -514,7 +529,7 @@ class RectangularBoggleBoard(AbstractBoggleBoard):
 
 
     def __str__(self):
-        """__str__:
+        """__str__
 
         Convert a Boggle board to a readable string."""
 
@@ -579,7 +594,7 @@ class RectangularToroidalBoggleBoard(RectangularBoggleBoard):
     neighbours, the edge letters are adjacent to five, and the corners three."""
 
     def _determineAdjacencies(self):
-        """_determineAdjacencies()
+        """_determineAdjacencies
 
         Create the adjacency graph to account for the left-right and top-bottom
         looping."""
@@ -635,7 +650,7 @@ class Anagram(AbstractBoggleBoard):
 
 
     def _determineAdjacencies(self):
-        """_determineAdjacencices()
+        """_determineAdjacencies()
 
         Should not be called by the end user.
         Create an adjacency graph where everyone is adjacent to everyone else."""
